@@ -159,3 +159,45 @@ tableHTML(mtcars, collapse = 'separate_shiny', spacing = '5px 2px') %>%
     add_css_table(css = list(c('background-color'), c('lightgray'))) %>% 
     add_css_table(css = list('color', 'blue'))
 
+## ----example_17----------------------------------------------------------
+tableHTML(mtcars,
+          widths = c(140, rep(50, 11)),
+          theme = 'scientific') %>%
+  add_css_row(css = list('background-color', '#E0E0E0'), rows = odd(3:34)) %>%
+  add_css_conditional_column(conditional = 'between',
+                             between = c(3.5, 4.22), 
+                             css = list(c('background-color'), c('gray')),
+                             columns = c('drat', 'wt')) %>%
+  add_css_header(css = list(c('transform', 'height'), 
+                            c('rotate(-45deg)', '40px')),
+                 headers = 1:12)
+
+
+## ----example_16----------------------------------------------------------
+tableHTML(iris[c(1:5, 51:55, 101:105), 1:4], 
+          rownames = FALSE,
+          headers = rep(c('Length', 'Width'), 2),
+          second_headers = list(c(1, 2, 2), c('Species', 'Sepal', 'Petal')),
+          row_groups = list(rep(5, 3), paste0('<div style="width:100%; height:100%; ',
+                                               'transform:rotate(-90deg); font-size:16px; ',
+                                               'font-weight:bold; color:white; align:center">', 
+                                               c('setosa', 'versicolor', 'virginica'),
+                                               '</div>'))) %>%
+  add_css_column(css = list(c('background-color', 'border'),
+                            c('gray', 'white')), 
+                 columns = 'row_groups') %>%
+  add_css_second_header(css = list(c('color', 'background-color'),
+                                   c('white', 'gray')),
+                        second_headers = 1:3) %>%
+  add_css_header(css = list(c('color', 'background-color'),
+                            c('white', 'gray')),
+                 headers = 1:5) %>%
+  add_css_conditional_column('colour_rank',
+                             colour_rank_theme = 'White-Green',
+                             columns = 1:2,
+                             same_scale = FALSE) %>%
+  add_css_conditional_column('colour_rank',
+                             colour_rank_theme = 'White-Blue',
+                             columns = 3:4,
+                             same_scale = FALSE)
+
